@@ -34,10 +34,17 @@ class RSSMixin(object):
         been parsed.
         """
         if parse:
-            for feed in self.feeds:
-                for item in parse(feed).entries:
+            for feed_url in self.feeds:
+                feed = parse(feed_url)
+                for item in feed.entries:
                     if item["id"] not in self.feed_items:
                         self.feed_items.add(item["id"])
                         if message_channel:
-                            self.message_channel("%(title)s: %(id)s" % item)
+                            message = self.format_item_message(feed, item)
+                            self.message_channel(message)
                             return
+
+    def format_item_message(self, feed, item):
+        item["feed_title"] = feed.feed.title or feed.url
+        return "%(title)s: %(id)s (via %(feed_title)s)" % item
+
